translate.storage.placeables.interfaces.ReplacementPlaceable

Package translate :: Package storage :: Package placeables :: Module interfaces :: Class ReplacementPlaceable |
[hide private]
[frames] | no frames]

# Class ReplacementPlaceable

source code

Instance Methods | [hide private]
Inherited from `strelem.StringElem`: `__add__`, `__contains__`, `__eq__`, `__ge__`, `__getitem__`, `__getslice__`, `__gt__`, `__init__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__mul__`, `__ne__`, `__radd__`, `__repr__`, `__rmul__`, `__str__`, `__unicode__`, `apply_to_strings`, `copy`, `delete_elem`, `delete_range`, `depth_first`, `elem_at_offset`, `elem_offset`, `encode`, `find`, `find_elems_with`, `flatten`, `get_ancestor_where`, `get_index_data`, `get_parent_elem`, `insert`, `insert_between`, `isleaf`, `iter_depth_first`, `map`, `print_tree`, `prune`, `remove_type`, `translate` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`

Class Variables | [hide private]
| parse = `None` Parse an instance of this class from the start of the given string.
Inherited from `strelem.StringElem`: `has_content`, `iseditable`, `isfragile`, `istranslatable`, `isvisible`, `renderer`, `sub`

Properties | [hide private]
Inherited from `object`: `__class__`